/// Copyright (c) 2012 Ecma International.  All rights reserved. 
/// Ecma International makes this code available under the terms and conditions set
/// forth on http://hg.ecmascript.org/tests/test262/raw-file/tip/LICENSE (the 
/// "Use Terms").   Any redistribution of this code must retain the above 
/// copyright and this notice and otherwise comply with the Use Terms.
/**
 * @path ch13/13.2/13.2-7-s.js
 * @description StrictMode - enumerating over a function object looking for 'caller' fails outside of the function
 * @onlyStrict
 */


function testcase() {
        var foo = new Function("'use strict';");
        
        for (var tempIndex in foo) {
            if (tempIndex === "caller") {
                return false;
            }
        }
        return true;
    }
runTestCase(testcase);
